Module: GitFit::Auth
- Defined in:
- lib/git_fit/auth/paths.rb,
lib/git_fit/auth/garmin.rb,
lib/git_fit/auth/strava.rb,
lib/git_fit/auth/garmin_token.rb,
lib/git_fit/auth/garmin/strategy_a.rb,
lib/git_fit/auth/garmin/strategy_b.rb,
lib/git_fit/auth/garmin/di_exchange.rb,
lib/git_fit/auth/garmin/login_session.rb
Defined Under Namespace
Modules: Garmin Classes: GarminToken, Strava
Class Method Summary collapse
-
.file(source, name) ⇒ Object
Canonical per-source auth storage: data/auth/source/name.
Class Method Details
.file(source, name) ⇒ Object
Canonical per-source auth storage: data/auth/source/name. All sync adapters, the auth orchestrator and strategies must resolve token/session defaults through this helper so they can never drift apart.
10 11 12 |
# File 'lib/git_fit/auth/paths.rb', line 10 def file(source, name) File.join('data', 'auth', source, name) end |